@@ -2,8 +2,9 @@
 """Query providers for metadata."""
 
 import os
+from ._core import EAN13
 from .registry import services
-from .exceptions import NotRecognizedServiceError
+from ._exceptions import NotRecognizedServiceError, NotValidISBNError
 from .config import options, CONF_PATH, CACHE_FILE
 from ._cache import Cache
 
@@ -33,11 +34,15 @@ CACHE = None if CACHE.lower() == 'no' else CACHE
 
 def query(isbn, service='default', cache=CACHE):
     """Query worldcat.org, Google Books (JSON API), ... for metadata."""
+    ean = EAN13(isbn)
+    if not ean:
+        raise NotValidISBNError(isbn)
+    isbn = ean
     if service != 'default' and service not in services:
         raise NotRecognizedServiceError(service)
-    if cache is None:
+    if cache is None:  # pragma: no cover
         return services[service](isbn)
-    kache = Cache() if cache == 'default' else Cache(cache)
+    kache = Cache(cache)
     key = isbn + service
     if kache[key]:
         return kache[key]
