@@ -5,9 +5,9 @@ import logging
 from isbntools.dev.webquery import query as wquery
 from isbntools.dev import stdmeta
 from isbntools.dev.bouth23 import u
-from isbntools.dev.exceptions import (DataWrongShapeError,
-                                      NoDataForSelectorError,
-                                      RecordMappingError)
+from isbntools.dev._exceptions import (DataWrongShapeError,
+                                       NoDataForSelectorError,
+                                       RecordMappingError)
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q={words}&fields='\
