@@ -3,7 +3,7 @@
 
 
 from ._helpers import normalize_space, titlecase
-from .exceptions import NotValidMetadataError
+from ._exceptions import NotValidMetadataError
 from .bouth23 import u, type3str
 
 # For now you cannot add custom fields!
@@ -61,12 +61,13 @@ class Metadata(object):
         """Delete value."""
         self._set_empty()
 
-    def merge(self, record, overwrite=(), overrule=lambda x: x == ''):
+    def merge(self, record, overwrite=(),
+              overrule=lambda x: x == u('') or x == [u('')]):
         """Merge the record with value."""
         # by default do nothing
         self._content.update((k, v) for k, v in list(record.items())
                              if k in overwrite and not overrule(v) or
-                             self._content[k] == '')
+                             self._content[k] == u(''))
         if not self._validate():  # pragma: no cover
             self._set_empty()
             raise NotValidMetadataError()
